/***********************************************************************************************************************************
Server Command
***********************************************************************************************************************************/
#ifndef COMMAND_SERVER_SERVER_H
#define COMMAND_SERVER_SERVER_H

#include <inttypes.h>

/***********************************************************************************************************************************
Functions
***********************************************************************************************************************************/
void cmdServer(unsigned int argListSize, const char *argList[]);

#endif
